"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomMessageProperties(str, Enum):
    ID = "id"
    NAME = "name"
    TEXT = "text"
    LABEL = "label"
    UPDATED_AT = "updated_at"
