"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing_extensions import NotRequired, TypedDict


class PromptHistoryTypedDict(TypedDict):
    r"""Record of a change to a prompt. Values reflect post-change state."""

    timestamp: datetime
    r"""Timestamp of the change"""
    prompt_id: str
    r"""ID of the prompt"""
    prompt_text: str
    r"""Text of the prompt"""
    prompt_name: str
    r"""Name of the prompt"""
    user_email: str
    r"""Email address of the user who made the change"""
    prompt_description: NotRequired[Nullable[str]]
    r"""Description of the prompt"""
    llm_config: NotRequired[Nullable[str]]
    r"""String representation of LLM config for the prompt"""
    comments: NotRequired[Nullable[str]]
    r"""Comments describing the change"""


class PromptHistory(BaseModel):
    r"""Record of a change to a prompt. Values reflect post-change state."""

    timestamp: datetime
    r"""Timestamp of the change"""

    prompt_id: str
    r"""ID of the prompt"""

    prompt_text: str
    r"""Text of the prompt"""

    prompt_name: str
    r"""Name of the prompt"""

    user_email: str
    r"""Email address of the user who made the change"""

    prompt_description: OptionalNullable[str] = UNSET
    r"""Description of the prompt"""

    llm_config: OptionalNullable[str] = UNSET
    r"""String representation of LLM config for the prompt"""

    comments: OptionalNullable[str] = UNSET
    r"""Comments describing the change"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["prompt_description", "llm_config", "comments"]
        nullable_fields = ["prompt_description", "llm_config", "comments"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
