"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class CommunicationRequestRequestVariablesTypedDict(TypedDict):
    r"""Variables for request"""


class CommunicationRequestRequestVariables(BaseModel):
    r"""Variables for request"""


class CommunicationRequestTypedDict(TypedDict):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""
    target: str
    r"""Target phone number or email address"""
    request_variables: CommunicationRequestRequestVariablesTypedDict
    r"""Variables for request"""


class CommunicationRequest(BaseModel):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""

    target: str
    r"""Target phone number or email address"""

    request_variables: CommunicationRequestRequestVariables
    r"""Variables for request"""
