"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceDisplayName(str, Enum):
    r"""Display names of voices that Syllable supports."""

    ALEJANDRO = "Alejandro"
    ALICE = "Alice"
    ALLOY = "Alloy"
    ASH = "Ash"
    BILL = "Bill"
    BRIAN = "Brian"
    CALLUM = "Callum"
    CHARLIE = "Charlie"
    CHARLOTTE = "Charlotte"
    CHRIS = "Chris"
    CLARA = "Clara"
    CORAL = "Coral"
    DANIEL = "Daniel"
    ECHO = "Echo"
    ERIC = "Eric"
    FABLE = "Fable"
    GEORGE = "George"
    ISABELLA = "Isabella"
    JERRY = "Jerry"
    JESSICA = "Jessica"
    LAURA = "Laura"
    LIAM = "Liam"
    LILY = "Lily"
    LINA = "Lina"
    MARK = "Mark"
    MATILDA = "Matilda"
    MELANIE = "Melanie"
    MILA = "Mila"
    NOVA = "Nova"
    ONYX = "Onyx"
    RIVER = "River"
    ROGER = "Roger"
    SARAH = "Sarah"
    SAGE = "Sage"
    SHIMMER = "Shimmer"
    SIENNA = "Sienna"
    TARA = "Tara"
    WILL = "Will"
