"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceModel(str, Enum):
    r"""Model for an agent voice."""

    MULTILINGUAL_V2 = "Multilingual_v2"
    NEURAL2 = "Neural2"
    STANDARD = "Standard"
    STUDIO = "Studio"
    WAVE_NET = "WaveNet"
    WHISPER = "Whisper"
