"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InsightsWorkflowQueueSessionTypedDict(TypedDict):
    r"""Session identifier for workflow queue."""

    workflow_name: str
    r"""Unique name for workflow"""
    session_id_list: List[int]
    r"""List of session identifiers"""


class InsightsWorkflowQueueSession(BaseModel):
    r"""Session identifier for workflow queue."""

    workflow_name: str
    r"""Unique name for workflow"""

    session_id_list: List[int]
    r"""List of session identifiers"""
