"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class InsightToolTestInputTypedDict(TypedDict):
    r"""Request model to test an insight tool."""

    tool_name: str
    r"""Human readable name of insight tool"""
    session_id: int
    r"""The session ID of the session to run the tool against"""


class InsightToolTestInput(BaseModel):
    r"""Request model to test an insight tool."""

    tool_name: str
    r"""Human readable name of insight tool"""

    session_id: int
    r"""The session ID of the session to run the tool against"""
