"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .communicationbatch import CommunicationBatch, CommunicationBatchTypedDict
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OutboundBatchUpdateRequestTypedDict(TypedDict):
    batch_id: str
    communication_batch: CommunicationBatchTypedDict


class OutboundBatchUpdateRequest(BaseModel):
    batch_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    communication_batch: Annotated[
        CommunicationBatch,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
