"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from syllable_sdk.batches import Batches
from syllable_sdk.campaigns import Campaigns


class Outbound(BaseSDK):
    batches: Batches
    r"""Operations related to outbound campaign batches"""
    campaigns: Campaigns
    r"""Operations related to outbound message campaigns"""

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.batches = Batches(self.sdk_configuration)
        self.campaigns = Campaigns(self.sdk_configuration)
