"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class IncidentOrganizationResponseTypedDict(TypedDict):
    id: int
    name: str
    display_name: str


class IncidentOrganizationResponse(BaseModel):
    id: int

    name: str

    display_name: str
